@@ -6,10 +6,23 @@
 #[allow(clippy::single_component_path_imports)]
 use gtk; // Required for the documentation to build without warnings
 
+use glib::translate::{FromGlib, TryFromGlib};
 use gtk::prelude::IsA;
-
 use gtk4_layer_shell_sys as ffi;
 
+impl TryFromGlib<ffi::GtkLayerShellLayer> for Layer {
+    type Error = glib::translate::GlibNoneError;
+
+    unsafe fn try_from_glib(value: ffi::GtkLayerShellLayer) -> Result<Self, Self::Error> {
+        let layer = unsafe { Self::from_glib(value) };
+        // If we got an unknown variant, return an error; otherwise, return the value.
+        match layer {
+            Layer::__Unknown(_) => Err(glib::translate::GlibNoneError),
+            _ => Ok(layer),
+        }
+    }
+}
+
 macro_rules! assert_initialized_main_thread {
     () => {
         if !::gtk::is_initialized_main_thread() {
@@ -34,7 +47,6 @@ pub use auto::{
 };
 
 mod manual;
-//use manual::*;
 
 pub trait LayerShell: IsA<gtk::Window> {
     /// When auto exclusive zone is enabled, exclusive zone is automatically set to the
@@ -107,7 +119,7 @@ pub trait LayerShell: IsA<gtk::Window> {
     /// the current layer.
     #[doc(alias = "gtk_layer_get_layer")]
     #[doc(alias = "get_layer")]
-    fn layer(&self) -> Layer {
+    fn layer(&self) -> Option<Layer> {
         crate::auto::functions::layer(self)
     }
 
@@ -257,7 +269,7 @@ pub trait LayerShell: IsA<gtk::Window> {
     /// ## `monitor`
     /// The output this layer surface will be placed on ([`None`] to let the compositor decide).
     #[doc(alias = "gtk_layer_set_monitor")]
-    fn set_monitor(&self, monitor: &gdk::Monitor) {
+    fn set_monitor(&self, monitor: Option<&gdk::Monitor>) {
         crate::auto::functions::set_monitor(self, monitor);
     }
 
@@ -274,7 +286,7 @@ pub trait LayerShell: IsA<gtk::Window> {
     /// ## `name_space`
     /// The namespace of this layer surface.
     #[doc(alias = "gtk_layer_set_namespace")]
-    fn set_namespace(&self, name_space: &str) {
+    fn set_namespace(&self, name_space: Option<&str>) {
         crate::auto::functions::set_namespace(self, name_space);
     }
 
